"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = void 0;
const errors_1 = require("./errors");
const fs_extra_1 = __importDefault(require("fs-extra"));
function getConfig() {
    return __awaiter(this, void 0, void 0, function* () {
        const env = filterAndTypecastEnvs(process.env);
        if (!env.hasuraCliPath) {
            throw new errors_1.MissingConfig('HASURA_CLI_PATH env not set');
        }
        if (!env.hasuraUri) {
            throw new errors_1.MissingConfig('HASURA_URI env not set');
        }
        if (!env.genesis.shelleyPath) {
            throw new errors_1.MissingConfig('GENESIS_FILE_SHELLEY env not set');
        }
        if (!env.postgresDbFile && !env.postgresDb) {
            throw new errors_1.MissingConfig('POSTGRES_DB_FILE or POSTGRES_DB env not set');
        }
        if (!env.postgresHost) {
            throw new errors_1.MissingConfig('POSTGRES_HOST env not set');
        }
        if (!env.postgresPasswordFile && !env.postgresPassword) {
            throw new errors_1.MissingConfig('POSTGRES_PASSWORD_FILE or POSTGRES_PASSWORD env not set');
        }
        if (!env.postgresPort) {
            throw new errors_1.MissingConfig('POSTGRES_PORT env not set');
        }
        if (!env.postgresUserFile && !env.postgresUser) {
            throw new errors_1.MissingConfig('POSTGRES_USER_FILE or POSTGRES_USER env not set');
        }
        let db;
        try {
            db = {
                database: env.postgresDb || (yield fs_extra_1.default.readFile(env.postgresDbFile, 'utf8')).toString(),
                host: env.postgresHost,
                password: env.postgresPassword || (yield fs_extra_1.default.readFile(env.postgresPasswordFile, 'utf8')).toString(),
                port: env.postgresPort,
                user: env.postgresUser || (yield fs_extra_1.default.readFile(env.postgresUserFile, 'utf8')).toString()
            };
        }
        catch (error) {
            throw new errors_1.MissingConfig('Database configuration cannot be read');
        }
        return Object.assign(Object.assign({}, env), { allowIntrospection: (process.env.NODE_ENV === 'production' && env.allowIntrospection) ||
                (process.env.NODE_ENV !== 'production' && env.allowIntrospection !== false), allowedOrigins: env.allowedOrigins || true, apiPort: env.apiPort || 3100, cacheEnabled: env.cacheEnabled || false, db, listenAddress: env.listenAddress || '0.0.0.0', queryDepthLimit: env.queryDepthLimit || 10 });
    });
}
exports.getConfig = getConfig;
function filterAndTypecastEnvs(env) {
    const { ALLOW_INTROSPECTION, ALLOWED_ORIGINS, ALLOW_LIST_PATH, API_PORT, CACHE_ENABLED, GENESIS_FILE_BYRON, GENESIS_FILE_SHELLEY, HASURA_CLI_PATH, HASURA_URI, LISTEN_ADDRESS, POSTGRES_DB, POSTGRES_DB_FILE, POSTGRES_HOST, POSTGRES_PASSWORD, POSTGRES_PASSWORD_FILE, POSTGRES_PORT, POSTGRES_USER, POSTGRES_USER_FILE, PROMETHEUS_METRICS, QUERY_DEPTH_LIMIT, TRACING } = env;
    return {
        allowIntrospection: ALLOW_INTROSPECTION === 'true',
        allowedOrigins: ALLOWED_ORIGINS,
        allowListPath: ALLOW_LIST_PATH,
        apiPort: Number(API_PORT),
        cacheEnabled: CACHE_ENABLED === 'true',
        genesis: {
            byronPath: GENESIS_FILE_BYRON,
            shelleyPath: GENESIS_FILE_SHELLEY
        },
        hasuraCliPath: HASURA_CLI_PATH,
        hasuraUri: HASURA_URI,
        listenAddress: LISTEN_ADDRESS,
        postgresDb: POSTGRES_DB,
        postgresDbFile: POSTGRES_DB_FILE,
        postgresHost: POSTGRES_HOST,
        postgresPassword: POSTGRES_PASSWORD,
        postgresPasswordFile: POSTGRES_PASSWORD_FILE,
        postgresPort: Number(POSTGRES_PORT),
        postgresUser: POSTGRES_USER,
        postgresUserFile: POSTGRES_USER_FILE,
        prometheusMetrics: PROMETHEUS_METRICS === 'true',
        queryDepthLimit: Number(QUERY_DEPTH_LIMIT),
        tracing: TRACING === 'true'
    };
}
//# sourceMappingURL=config.js.map